<?php
/**
 * Xanatek functions and definitions
 *
 * This file must be parseable by PHP 5.2.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package xanatek
 */

define( 'XANATEK_MINIMUM_WP_VERSION', '4.5' );
define( 'XANATEK_MINIMUM_PHP_VERSION', '7.0' );

// Bail if requirements are not met.
if ( version_compare( $GLOBALS['wp_version'], XANATEK_MINIMUM_WP_VERSION, '<' ) || version_compare( phpversion(), XANATEK_MINIMUM_PHP_VERSION, '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

// Include WordPress shims.
require get_template_directory() . '/inc/wordpress-shims.php';

// Setup autoloader (via Composer or custom).
if ( file_exists( get_template_directory() . '/vendor/autoload.php' ) ) {
	require get_template_directory() . '/vendor/autoload.php';
} else {
	/**
	 * Custom autoloader function for theme classes.
	 *
	 * @access private
	 *
	 * @param string $class_name Class name to load.
	 * @return bool True if the class was loaded, false otherwise.
	 */
	function _xanatek_autoload( $class_name ) {
		$namespace = 'WP_Rig\WP_Rig';

		if ( strpos( $class_name, $namespace . '\\' ) !== 0 ) {
			return false;
		}

		$parts = explode( '\\', substr( $class_name, strlen( $namespace . '\\' ) ) );

		$path = get_template_directory() . '/inc';
		foreach ( $parts as $part ) {
			$path .= '/' . $part;
		}
		$path .= '.php';

		if ( ! file_exists( $path ) ) {
			return false;
		}

		require_once $path;

		return true;
	}
	spl_autoload_register( '_xanatek_autoload' );
}

// Load the `xanatek()` entry point function.
require get_template_directory() . '/inc/functions.php';

// Initialize the theme.
call_user_func( 'WP_Rig\WP_Rig\xanatek' );

/**
 * Display Posts Output Filter
 * @see https://displayposts.com/docs/the-output-filter/
 *
 */
function be_dps_output_customization( $output, $original_atts, $image, $title, $date, $excerpt, $inner_wrapper, $content, $class, $author, $category_display_text ) {

	// Get our custom fields
	global $post;
	$name = esc_attr( get_post_meta( $post->ID, 'review_author_name', true ) );
	$position = esc_attr( get_post_meta( $post->ID, 'review_author_position', true ) );
	$company = esc_attr( get_post_meta( $post->ID, 'review_company', true ) );
	$location = esc_attr( get_post_meta( $post->ID, 'review_city_state', true ) );

	// If there's a value for the custom field, let's wrap them with <span>'s so you can control them with CSS
	if( isset( $name ) ) $name = '<span class="author">' . $name . '</span> ';
	if( isset( $position ) ) $position = '<span class="position">' . $position . '</span> ';
	if( isset( $company ) ) $company = '<span class="company">' . $company . '</span> ';
	if( isset( $location ) ) $location = '<span class="location">' . $location . '</span> ';

	$output = '<' . $inner_wrapper . ' class="' . implode( ' ', $class ) . '">' . $content . $name . $position . $company . $location . '</' . $inner_wrapper . '>';
	return $output;
  }
  add_filter( 'display_posts_shortcode_output', 'be_dps_output_customization', 10, 11 );
