<?php
/**
 * WP_Rig\WP_Rig\Accordion\Component class
 *
 * @package xanatek
 */

namespace WP_Rig\WP_Rig\Accordion;

use WP_Rig\WP_Rig\Component_Interface;
use WP_Rig\WP_Rig\Templating_Component_Interface;
use function WP_Rig\WP_Rig\xanatek;
use function get_the_category;
use function add_action;
use function wp_enqueue_script;
use function get_theme_file_uri;
use function get_theme_file_path;
use function wp_script_add_data;
use function wp_localize_script;
use function get_the_ID;
use function rest_url;
use function esc_html__;
use function add_image_size;

/**
 * Class for related posts.
 *
 * Exposes template tags:
 * * `xanatek()->the_comments( array $args = array() )`
 *
 * @link https://wordpress.org/plugins/amp/
 */
class Component implements Component_Interface, Templating_Component_Interface {

	/**
	 * Gets the unique identifier for the theme component.
	 *
	 * @return string Component slug.
	 */
	public function get_slug() : string {
		return 'accordion';
	}

	/**
	 * Adds the action and filter hooks to integrate with WordPress.
	 */
	public function initialize() {
		add_action( 'wp_enqueue_scripts', array( $this, 'action_enqueue_accordion_script' ) );
	}

	/**
	 * Gets template tags to expose as methods on the Template_Tags class instance, accessible through `xanatek()`.
	 *
	 * @return array Associative array of $method_name => $callback_info pairs. Each $callback_info must either be
	 *               a callable or an array with key 'callable'. This approach is used to reserve the possibility of
	 *               adding support for further arguments in the future.
	 */
	public function template_tags() : array {
		return array(
			'display_accordion' => array( $this, 'display_accordion' ),
		);
	}

	/**
	 * Enqueues the accordion script file.
	 */
	public function action_enqueue_accordion_script() {

		// If the AMP plugin is active, return early.
		if ( xanatek()->is_amp() ) {
			return;
		}

		// Enqueue the accordion script.
			wp_enqueue_script(
				'xanatek-accordion',
				get_theme_file_uri( '/assets/js/accordion.min.js' ),
				array(),
				xanatek()->get_asset_version( get_theme_file_path( '/assets/js/accordion.min.js' ) ),
				false
			);
			wp_script_add_data( 'xanatek-accordion', 'defer', true );
	}


	/**
	 * Display the accordion.
	 */
	public function display_accordion() {

	}
}
